@@ -1,10 +1,10 @@
 package PAR::Packer;
+$PAR::Packer::VERSION = '0.970';
+
 use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.992_06';
-
 =head1 NAME
 
 PAR::Packer - PAR Packager
@@ -42,10 +42,8 @@ use constant OPTIONS => {
     'B|bundle'       => 'Bundle core modules',
     'C|clean',       => 'Clean up temporary files',
     'c|compile'      => 'Compile code to get dependencies',
-    'cd|cachedeps:s' => 'Cache detected dependencies in a file',
     'd|dependent'    => 'Do not include libperl',
     'e|eval:s'       => 'Packing one-liner',
-    'E|evalfeature:s'=> 'Packing one-liner with new syntactic features',
     'x|execute'      => 'Execute code to get dependencies',
     'X|exclude:s@'   => 'Exclude modules',
     'f|filter:s@'    => 'Input filters for scripts',
@@ -63,7 +61,6 @@ use constant OPTIONS => {
     'p|par'          => 'Generate PAR file',
     'P|perlscript'   => 'Generate perl script',
     'r|run'          => 'Run the resulting executable',
-    'reusable'       => 'Produce reusable executable',
     'S|save'         => 'Preserve intermediate PAR files',
     's|sign'         => 'Sign PAR files',
     'T|tempcache:s'  => 'Temp cache name',
@@ -74,7 +71,7 @@ use constant OPTIONS => {
 };
 
 my $ValidOptions = {};
-my $LongToShort = { map { /^(\w+)\|(\w+)/ ? ($1, $2) : () } grep /\|/, keys %{+OPTIONS} };
+my $LongToShort = { map { /^(\w+)\|(\w+)/ ? ($1, $2) : () } keys %{+OPTIONS} };
 my $ShortToLong = { reverse %$LongToShort };
 my $PerlExtensionRegex = qr/\.(?:al|ix|p(?:lx|l|h|m))\z/i;
 my (%dep_zips, %dep_zip_files);
@@ -89,6 +86,14 @@ sub new {
     # exit gracefully and clean up after ourselves.
     # note.. in constructor because of conflict.
 
+    # Up to PAR 0.957, we set the following ENV variable, but
+    # it is never, ever used anywhere in the rest of the
+    # PAR or M::SD sources, so in order to remove clutter, we
+    # comment it out. This notice and the following commented
+    # out line should be removed in a future version if no
+    # breakage occurred.
+
+    # $ENV{PAR_RUN} = 1;
     my $self = bless {}, $class;
 
     $self->set_args($args)      if ($args);
@@ -136,7 +141,7 @@ sub _translate_options {
         else {
             $opt->{$key} = $value;
             my $other = $LongToShort->{$key} || $ShortToLong->{$key};
-            $opt->{$other} = $value if defined $other;
+            $opt->{$other} = $value;
         }
     }
 }
@@ -158,7 +163,6 @@ sub set_front {
     $self->{frontend} = $frontend || $opt->{frontend};
 }
 
-# check one or more files for read permissions
 sub _check_read {
     my ($self, @files) = @_;
 
@@ -180,7 +184,6 @@ sub _check_read {
     }
 }
 
-# check one or more files for write permissions
 sub _check_write {
     my ($self, @files) = @_;
 
@@ -197,7 +200,6 @@ sub _check_write {
     }
 }
 
-# check whether a given file might contain perl code (including .par's)
 sub _check_perl {
     my ($self, $file) = @_;
     return if ($self->_check_par($file));
@@ -292,19 +294,13 @@ sub _parse_opts {
     $opt->{z} = Archive::Zip::COMPRESSION_LEVEL_DEFAULT if $opt->{z} < 0;
     $opt->{z} = 9 if $opt->{z} > 9;
 
+    $self->{output}      = $opt->{o}            || $self->_a_out();
     $opt->{o}            = $opt->{o}            || $self->_a_out();
-    $self->{output}      = $opt->{o};
     $self->{script_name} = $self->{script_name} || $opt->{script_name} || $0;
 
     $self->{logfh} = $self->_open('>>', $opt->{L})
       if length $opt->{L};
 
-    if ($opt->{E}) {
-        $opt->{e} = "use $];\n#line 1\n$opt->{E}";
-        # XXX This is how we should also include additional default modules in the future instead of in require_modules in par.pl!
-        push @{ $opt->{M} ||= [] }, 'feature' if $] >= 5.009;
-    }
-
     if ($opt->{e}) {
         $self->_warn("Using -e 'code' as input file, ignoring @$args\n")
           if (@$args and !$opt->{r});
@@ -319,15 +315,6 @@ sub _parse_opts {
     else {
         $self->{input} ||= [];
 
-        # Reject main.pl as input file to avoid beginner confusion
-        if ( grep /main\.pl$/,
-             ($opt->{r} ? ($args->[0]) : @$args) )
-        {
-          # -r means "run this" => extra args are execution parameters
-
-          $self->_die( "Cannot package 'main.pl' script. This file name "
-                      ."is used by PAR::Packer internally for bootstrapping.");
-        }
         push(@{ $self->{input} }, shift @$args) if (@$args);
 
         push(@{ $self->{input} }, @$args) if (@$args and !$opt->{r});
@@ -366,7 +353,6 @@ sub _create_valid_hash {
     }
 }
 
-# prints a dump of the OPTIONS hash
 sub _show_usage {
     my ($self) = @_;
 
@@ -439,9 +425,7 @@ sub run_pack {
     my $output = $self->{output};
     my $args   = $self->{args};
 
-    if (!File::Spec->file_name_is_absolute($output)) {
-	$output = File::Spec->catfile(".", $output);
-    }
+    $output = File::Spec->catfile(".", $output);
 
     my @loader = ();
     push(@loader, $^X) if ($opt->{P});
@@ -590,7 +574,7 @@ YAML
         $dep_list = join ', ', keys %dep_zips;
         $self->_vprint(0, "$self->{output} will require $dep_list at runtime");
 
-        $manifest =~ s/\Q$_\E\n// for (keys %dep_zip_files);
+        $manifest =~ s/$_\n// for (keys %dep_zip_files);
     }
 
     $self->_vprint(2, "... updating $_") for qw(MANIFEST META.yml);
@@ -615,7 +599,7 @@ sub get_par_file {
         # We need to keep it.
 
         if ($opt->{e} or !@$input) {
-            $par_file = (defined $output ? $output : "a.par");
+            $par_file = "a.par";
         }
         else {
             $par_file = $input->[0];
@@ -625,7 +609,8 @@ sub get_par_file {
             $par_file .= ".par";
         }
 
-        $par_file = $output if $opt->{p};
+        $par_file = $output if $opt->{p} and $output =~ /\.par\z/i;
+        $output = $par_file if $opt->{p};
 
         $self->_check_write($par_file);
     }
@@ -669,11 +654,6 @@ sub pack_manifest_hash {
     $root = "$Config{archname}/" if ($opt->{m});
     $self->{pack_attrib}{root} = '';
 
-    my @mscandeps_cache;
-    if (defined $opt->{cachedeps}) {
-        @mscandeps_cache = (cache_file => $opt->{cachedeps});
-    }
-
     my $par_file = $self->{par_file};
     my (@modules, @data, @exclude);
 
@@ -681,9 +661,6 @@ sub pack_manifest_hash {
         $self->_name2moddata($name, \@modules, \@data);
     }
 
-    # Skip either
-    # a) all files from a .par file or
-    # b) A module
     foreach my $name ('PAR', @{ $opt->{X} || [] }) {
         if (-f $name and my $dep_zip = Archive::Zip->new($name)) {
             for ($dep_zip->memberNames()) {
@@ -717,8 +694,7 @@ sub pack_manifest_hash {
     # Apply %Preload to the -M'd modules and add them to the list of
     # files to scan
     foreach my $module (@modules) {
-        my $file = &$inc_find($module)
-          or $self->_die("Cannot find module $module (specified with -M)\n");
+        my $file = &$inc_find($module);
         push @files, $file;
         
         my $preload = Module::ScanDeps::_get_preload($module) or next;
@@ -742,14 +718,12 @@ sub pack_manifest_hash {
       ? $self->_obj_function($fe, 'scan_deps_runtime')
       : $self->_obj_function($fe, 'scan_deps');
 
-
     $scan_dispatch->(
         rv      => \%map,
         files   => \@files,
         execute => $opt->{x},
         compile => $opt->{c},
         skip    => \%skip,
-        @mscandeps_cache,
         ($opt->{n}) ? () : (
             recurse => 1,
             first   => 1,
@@ -891,6 +865,7 @@ sub pack_manifest_hash {
 
     $dep_manifest->{'MANIFEST'} = [ string => "<<placeholder>>" ];
     $dep_manifest->{'META.yml'} = [ string => "<<placeholder>>" ];
+
     return ($dep_manifest);
 }
 
@@ -1268,9 +1243,13 @@ sub _par_to_exe {
         $self->_append_parl();
         $self->_generate_output();
 
+        Win32::Exe->new($output)->update(
+            icon => $opt->{i},
+            info => $opt->{N},
+        );
+
         $self->_fix_console();
         unlink($self->{parl});
-        unlink($self->{orig_parl});
         unlink("$self->{parl}.bak");
         return;
     }
@@ -1385,11 +1364,8 @@ sub _generate_output {
     my $output   = $self->{output};
     my $par_file = $self->{par_file};
 
-    my @args = ("-O$output", $par_file);
+    my @args = ('-B', "-O$output", $par_file);
     unshift @args, '-q' unless $opt->{v} > 0;
-    if ($opt->{B}) {
-        unshift @args, "-B";
-    } 
     if ($opt->{L}) {
         unshift @args, "-L".$opt->{L};
     }
@@ -1586,13 +1562,9 @@ sub _can_run {
 sub _main_pl_multi {
     my ($self) = @_;
    
-    # insert code for @INC cleaning (in case of bundling core modules)
     my $clean_inc = $self->_main_pl_clean();
-    # insert code for reusable apps
-    my $reuse_app = $self->_main_pl_reuse();
-
-    # FIXME The $reuse_app code was written for _main_pl_single -- is it correct for this as well?
-    return $reuse_app . "\n" . <<'__MAIN__' . $clean_inc . "PAR::_run_member(\$member, 1);\n\n";
+    
+    return << '__MAIN__' . $clean_inc . "PAR::_run_member(\$member, 1);\n\n";
 my $file = $ENV{PAR_PROGNAME};
 my $zip = $PAR::LibCache{$ENV{PAR_PROGNAME}} || Archive::Zip->new(__FILE__);
 $file =~ s/^.*[\/\\]//;
@@ -1621,15 +1593,9 @@ sub _open {
 sub _main_pl_single {
     my ($self, $file) = @_;
     
-    # insert code for @INC cleaning (in case of bundling core modules)
     my $clean_inc = $self->_main_pl_clean();
-    # insert code for reusable apps
-    my $reuse_app = $self->_main_pl_reuse();
 
     return << "__MAIN__";
-
-$reuse_app
-
 my \$zip = \$PAR::LibCache{\$ENV{PAR_PROGNAME}} || Archive::Zip->new(__FILE__);
 my \$member = eval { \$zip->memberNamed('$file') }
         or die qq(main.pl: Can't open perl script "$file": No such file or directory (\$zip));
@@ -1641,39 +1607,6 @@ PAR::_run_member(\$member, 1);
 __MAIN__
 }
 
-sub _main_pl_reuse {
-    my $self = shift;
-
-    my $opt = $self->{options};
-
-    if (!$opt->{reusable}) {
-      return <<'__NOT_REUSABLE__';
-if (defined $ENV{PAR_APP_REUSE}) {
-    warn "Executable was created without the --reusable option. See 'perldoc pp'.\n";
-    exit(1);
-}
-__NOT_REUSABLE__
-    }
-
-    # insert code for @INC cleaning (in case of bundling core modules)
-    my $clean_inc = $self->_main_pl_clean();
-
-    my $reuse = <<__REUSE_APP__;
-if (defined \$ENV{PAR_APP_REUSE}) {
-    my \$filename = \$ENV{PAR_APP_REUSE};
-    delete \$ENV{PAR_APP_REUSE};
-    \$ENV{PAR_0} = \$filename;
-
-    $clean_inc
-
-    PAR::_run_external_file(\$filename, 1);
-    exit();
-}
-__REUSE_APP__
-
-    return $reuse;
-}
-
 sub _main_pl_clean {
     my $self = shift;
     my $opt = $self->{options};
@@ -1710,8 +1643,6 @@ sub DESTROY {
     unlink $self->{parl} if $self->{parl_is_temporary};
 }
 
-
-
 1;
 
 =head1 SEE ALSO
@@ -1738,7 +1669,7 @@ Please submit bug reports to E<lt>bug-par@rt.cpan.orgE<gt>.
 
 =head1 COPYRIGHT
 
-Copyright 2004-2009 by Audrey Tang E<lt>cpan@audreyt.orgE<gt>.
+Copyright 2004, 2005, 2006 by Audrey Tang E<lt>cpan@audreyt.orgE<gt>.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
