@@ -1,4 +1,5 @@
 #!/usr/bin/perl
+
 eval 'exec /usr/bin/perl  -S $0 ${1+"$@"}'
     if 0; # not running under some shell
 
@@ -158,49 +159,10 @@ followed by a 8-bytes magic string: "C<\012PAR.pm\012>".
 
 my ($par_temp, $progname, @tmpfile);
 END { if ($ENV{PAR_CLEAN}) {
-    require File::Temp;
-    require File::Basename;
-    require File::Spec;
-    my $topdir = File::Basename::dirname($par_temp);
-    outs(qq{Removing files in "$par_temp"});
-    File::Find::finddepth(sub { ( -d ) ? rmdir : unlink }, $par_temp);
+    unlink @tmpfile;
+    rmdir $par_temp;
+    $par_temp =~ s{[^\\/]*[\\/]?$}{};
     rmdir $par_temp;
-    # Don't remove topdir because this causes a race with other apps
-    # that are trying to start.
-
-    if (-d $par_temp && $^O ne 'MSWin32') {
-        # Something went wrong unlinking the temporary directory.  This
-        # typically happens on platforms that disallow unlinking shared
-        # libraries and executables that are in use. Unlink with a background
-        # shell command so the files are no longer in use by this process.
-        # Don't do anything on Windows because our parent process will
-        # take care of cleaning things up.
-
-        my $tmp = new File::Temp(
-            TEMPLATE => 'tmpXXXXX',
-            DIR => File::Basename::dirname($topdir),
-            SUFFIX => '.cmd',
-            UNLINK => 0,
-        );
-
-        print $tmp "#!/bin/sh
-x=1; while [ \$x -lt 10 ]; do
-   rm -rf '$par_temp'
-   if [ \! -d '$par_temp' ]; then
-       break
-   fi
-   sleep 1
-   x=`expr \$x + 1`
-done
-rm '" . $tmp->filename . "'
-";
-            chmod 0700,$tmp->filename;
-        my $cmd = $tmp->filename . ' >/dev/null 2>&1 &';
-        close $tmp;
-        system($cmd);
-        outs(qq(Spawned background process to perform cleanup: )
-             . $tmp->filename);
-    }
 } }
 
 BEGIN {
@@ -377,9 +339,8 @@ my ($start_pos, $data_pos);
 my @par_args;
 my ($out, $bundle, $logfh, $cache_name);
 
-delete $ENV{PAR_APP_REUSE}; # sanitize (REUSE may be a security problem)
-
 $quiet = 0 unless $ENV{PAR_DEBUG};
+
 # Don't swallow arguments for compiled executables without --par-options
 if (!$start_pos or ($ARGV[0] eq '--par-options' && shift)) {
     my %dist_cmd = qw(
@@ -389,61 +350,47 @@ if (!$start_pos or ($ARGV[0] eq '--par-options' && shift)) {
         s   sign_par
         v   verify_par
     );
+    while (@ARGV) {
+        $ARGV[0] =~ /^-([AIMOBLbqpiusTv])(.*)/ or last;
 
-    # if the app is invoked as "appname --par-options --reuse PROGRAM @PROG_ARGV",
-    # use the app to run the given perl code instead of anything from the
-    # app itself (but still set up the normal app environment and @INC)
-    if (@ARGV and $ARGV[0] eq '--reuse') {
-        shift @ARGV;
-        $ENV{PAR_APP_REUSE} = shift @ARGV;
-    }
-    else { # normal parl behaviour
-
-        my @add_to_inc;
-        while (@ARGV) {
-            $ARGV[0] =~ /^-([AIMOBLbqpiusTv])(.*)/ or last;
-
-            if ($1 eq 'I') {
-                push @add_to_inc, $2;
-            }
-            elsif ($1 eq 'M') {
-                eval "use $2";
-            }
-            elsif ($1 eq 'A') {
-                unshift @par_args, $2;
-            }
-            elsif ($1 eq 'O') {
-                $out = $2;
-            }
-            elsif ($1 eq 'b') {
-                $bundle = 'site';
-            }
-            elsif ($1 eq 'B') {
-                $bundle = 'all';
-            }
-            elsif ($1 eq 'q') {
-                $quiet = 1;
-            }
-            elsif ($1 eq 'L') {
-                open $logfh, ">>", $2 or die "XXX: Cannot open log: $!";
-            }
-            elsif ($1 eq 'T') {
-                $cache_name = $2;
-            }
-
-            shift(@ARGV);
-
-            if (my $cmd = $dist_cmd{$1}) {
-                delete $ENV{'PAR_TEMP'};
-                init_inc();
-                require PAR::Dist;
-                &{"PAR::Dist::$cmd"}() unless @ARGV;
-                &{"PAR::Dist::$cmd"}($_) for @ARGV;
-                exit;
-            }
+        if ($1 eq 'I') {
+            unshift @INC, $2;
+        }
+        elsif ($1 eq 'M') {
+            eval "use $2";
+        }
+        elsif ($1 eq 'A') {
+            unshift @par_args, $2;
+        }
+        elsif ($1 eq 'O') {
+            $out = $2;
+        }
+        elsif ($1 eq 'b') {
+            $bundle = 'site';
+        }
+        elsif ($1 eq 'B') {
+            $bundle = 'all';
+        }
+        elsif ($1 eq 'q') {
+            $quiet = 1;
+        }
+        elsif ($1 eq 'L') {
+            open $logfh, ">>", $2 or die "XXX: Cannot open log: $!";
+        }
+        elsif ($1 eq 'T') {
+            $cache_name = $2;
         }
 
-        unshift @INC, @add_to_inc;
+        shift(@ARGV);
+
+        if (my $cmd = $dist_cmd{$1}) {
+            delete $ENV{'PAR_TEMP'};
+            init_inc();
+            require PAR::Dist;
+            &{"PAR::Dist::$cmd"}() unless @ARGV;
+            &{"PAR::Dist::$cmd"}($_) for @ARGV;
+            exit;
+        }
     }
 }
 
@@ -459,6 +406,7 @@ if ($out) {
         require Archive::Zip;
     }
 
+
     my $par = shift(@ARGV);
     my $zip;
 
@@ -525,7 +473,6 @@ if ($out) {
         require PAR::Heavy;
         PAR::Heavy::_init_dynaloader();
         init_inc();
-
         require_modules();
 
         my @inc = sort {
@@ -540,13 +487,8 @@ if ($out) {
 
         if ($Config{_delim} eq '\\') { s{\\}{/}g for @inc }
 
-        # File exists test added to fix RT #41790:
-        # Funny, non-existing entry in _<....auto/Compress/Raw/Zlib/autosplit.ix.
-        # This is a band-aid fix with no deeper grasp of the issue.
-        # Somebody please go through the pain of understanding what's happening,
-        # I failed. -- Steffen
         my %files;
-        /^_<(.+)$/ and -e $1 and $files{$1}++ for keys %::;
+        /^_<(.+)$/ and $files{$1}++ for keys %::;
         $files{$_}++ for values %INC;
 
         my $lib_ext = $Config::Config{lib_ext};
@@ -691,13 +633,8 @@ if ($out) {
             }x;
             my $extract_name = $1;
             my $dest_name = File::Spec->catfile($ENV{PAR_TEMP}, $extract_name);
-            if (-f $dest_name && -s _ == $member->uncompressedSize()) {
-                outs(qq(Skipping "$member_name" since it already exists at "$dest_name"));
-            } else {
-                outs(qq(Extracting "$member_name" to "$dest_name"));
-                $member->extractToFileNamed($dest_name);
-                chmod(0555, $dest_name) if $^O eq "hpux";
-            }
+            $member->extractToFileNamed($dest_name);
+            outs(qq(Extracting "$member_name" to "$dest_name"));
         }
     }
     # }}}
@@ -722,7 +659,7 @@ sub CreatePath {
     
     require File::Path;
     
-    File::Path::mkpath($path) unless(-e $path); # mkpath dies with error
+	File::Path::mkpath($path) unless(-e $path); # mkpath dies with error
 }
 
 sub require_modules {
@@ -736,7 +673,6 @@ sub require_modules {
     require vars;
     require Carp;
     require Carp::Heavy;
-    require Errno;
     require Exporter::Heavy;
     require Exporter;
     require Fcntl;
@@ -752,17 +688,12 @@ sub require_modules {
     require PAR::Heavy;
     require PAR::Dist;
     require PAR::Filter::PodStrip;
-    eval { require Cwd };
-    eval { require Win32 };
     eval { require Scalar::Util };
-    eval { require Archive::Unzip::Burst };
-    eval { require Tie::Hash::NamedCapture };
 }
 
 # The C version of this code appears in myldr/mktmpdir.c
-# This code also lives in PAR::SetupTemp as set_par_temp_env!
 sub _set_par_temp {
-    if (defined $ENV{PAR_TEMP} and $ENV{PAR_TEMP} =~ /(.+)/) {
+    if ($ENV{PAR_TEMP} and $ENV{PAR_TEMP} =~ /(.+)/) {
         $par_temp = $1;
         return;
     }
@@ -771,7 +702,7 @@ sub _set_par_temp {
         (map $ENV{$_}, qw( PAR_TMPDIR TMPDIR TEMPDIR TEMP TMP )),
         qw( C:\\TEMP /tmp . )
     ) {
-        next unless defined $path and -d $path and -w $path;
+        next unless $path and -d $path and -w $path;
         my $username;
         my $pwuid;
         # does not work everywhere:
@@ -854,9 +785,8 @@ sub _tempfile {
     return($fh, $filename);
 }
 
-# same code lives in PAR::SetupProgname::set_progname
 sub _set_progname {
-    if (defined $ENV{PAR_PROGNAME} and $ENV{PAR_PROGNAME} =~ /(.+)/) {
+    if ($ENV{PAR_PROGNAME} and $ENV{PAR_PROGNAME} =~ /(.+)/) {
         $progname = $1;
     }
 
@@ -893,8 +823,8 @@ sub _fix_progname {
     }
 
     # XXX - hack to make PWD work
-    my $pwd = (defined &Cwd::getcwd) ? Cwd::getcwd()
-                : ((defined &Win32::GetCwd) ? Win32::GetCwd() : `pwd`);
+    my $pwd = (defined &Win32::GetCwd) ? Win32::GetCwd() : $ENV{PWD};
+    $pwd = `pwd` if !defined $pwd;
     chomp($pwd);
     $progname =~ s/^(?=\.\.?\Q$Config{_delim}\E)/$pwd$Config{_delim}/;
 
@@ -976,8 +906,7 @@ L<PAR>, L<PAR::Dist>, L<parl>, L<pp>
 
 =head1 AUTHORS
 
-Audrey Tang E<lt>cpan@audreyt.orgE<gt>,
-Steffen Mueller E<lt>smueller@cpan.orgE<gt>
+Audrey Tang E<lt>cpan@audreyt.orgE<gt>
 
 L<http://par.perl.org/> is the official PAR website.  You can write
 to the mailing list at E<lt>par@perl.orgE<gt>, or send an empty mail to
@@ -987,7 +916,8 @@ Please submit bug reports to E<lt>bug-par@rt.cpan.orgE<gt>.
 
 =head1 COPYRIGHT
 
-Copyright 2002-2009 by Audrey Tang E<lt>cpan@audreyt.orgE<gt>.
+Copyright 2002, 2003, 2004, 2005, 2006 by Audrey Tang
+E<lt>cpan@audreyt.orgE<gt>.
 
 Neither this program nor the associated L<parl> program impose any
 licensing restrictions on files generated by their execution, in
